# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.contrib.auth import get_user_model
from django.contrib.auth.models import AbstractUser, UserManager as BaseUserManager
from django.core.exceptions import ValidationError
from django.utils.encoding import python_2_unicode_compatible


class UserManager(BaseUserManager):
    def create_superuser(self, email, password, **extra_fields):
        return super(UserManager, self).create_superuser(email, email, password, **extra_fields)


@python_2_unicode_compatible
class User(AbstractUser):
    middle_name = models.CharField('Отчество', max_length=30, blank=True)

    objects = UserManager()

    USERNAME_FIELD = 'email'
    REQUIRED_FIELDS = []

    class Meta:
        db_table = 'auth_user'
        verbose_name = 'Пользователь'
        verbose_name_plural = 'Пользователи'

    def get_username(self):
        if self.is_staff:
            return self.username
        return self.email or '<anonymous>'

    def __str__(self):
        return self.get_username()

    def get_full_name(self):
        full_name = ' '.join([self.last_name, self.first_name, self.middle_name])
        full_name = full_name.strip()
        if full_name:
            return full_name
        return ''

    def get_short_name(self):
        short_name = super(User, self).get_short_name()
        if short_name:
            return short_name
        return self.email

    def validate_unique(self, exclude=None):
        super(User, self).validate_unique(exclude)
        if self.email and get_user_model().objects.exclude(id=self.id).filter(is_active=True, email__exact=self.email).exists():
            msg = 'Пользователь с e-mail адресом "{}" уже существует'
            raise ValidationError({'email': msg.format(self.email)})
