# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.conf import settings
from django.core.urlresolvers import reverse
from cms.toolbar_base import CMSToolbar
from cms.toolbar_pool import toolbar_pool
from cms.toolbar.items import Break, SideframeItem
from cms.cms_toolbars import ADMIN_MENU_IDENTIFIER, ADMINISTRATION_BREAK, LANGUAGE_MENU_IDENTIFIER
from django.utils.translation import ugettext_lazy as _


@toolbar_pool.register
class ExtendAdminMenuToolbar(CMSToolbar):

    def populate(self):
        if len(settings.LANGUAGES) == 1:
            language_menu = self.toolbar.get_menu(LANGUAGE_MENU_IDENTIFIER)
            if language_menu:
                self.toolbar.remove_item(language_menu)

        admin_menu = self.toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER, 'Настройки сайта')

        search_result = admin_menu.find_first(SideframeItem, name='{}...'.format(_('Users')))
        if search_result:
            admin_menu.remove_item(search_result.item)

        position = admin_menu.find_first(Break, identifier=ADMINISTRATION_BREAK) + 1

        user_menu = admin_menu.get_or_create_menu('user_menu', 'Пользователи и группы', position=position)
        user_menu.add_sideframe_item('Пользователи', url=reverse('admin:email_auth_user_changelist'))
        user_menu.add_sideframe_item('Группы', url=reverse('admin:auth_group_changelist'))

        tech_menu = admin_menu.get_or_create_menu('tech_menu', 'Технические настройки', position=position + 1)

        tech_menu.add_link_item('sitemap.xml', url='/sitemap.xml')
        tech_menu.add_link_item('robots.txt', url='/robots.txt')
        tech_menu.add_break()

        tech_menu.add_sideframe_item('Сайты', url=reverse('admin:sites_site_changelist'))

        # help
        help_menu = self.toolbar.get_or_create_menu('help_menu', 'Помощь')
        # help_menu.add_modal_item('Администрирование сайта', url=reverse('specs'))
        help_menu.add_link_item('Руководство пользователя Django CMS', url='http://vits.pro/info/django-cms/')

        # analytics items
        # analytics_menu = admin_menu.get_or_create_menu('analytics_menu', 'Аналитика', position=position + 2)
        # analytics_menu.add_link_item('Google Analytics', url='http://www.google.com/intl/ru_ru/analytics/')
        # analytics_menu.add_link_item('Яндекс.Метрика', url='https://metrika.yandex.ru/')